@@ -20,9 +20,10 @@
 #           Pierre-Yves Chibon <pingou@pingoured.fr>
 #
 
-from fasshim import gravatar_url, gravatar_url_from_email, email2fas
+from fedmsg_meta_fedora_infrastructure.fasshim import \
+        avatar_url, avatar_url_from_email, email2fas
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-
+import fedmsg.meta.base
 
 class AnityaProcessor(BaseProcessor):
     topic_prefix_re = 'org\\.release-monitoring\\.(dev|stg|prod)'
@@ -37,19 +38,27 @@ class AnityaProcessor(BaseProcessor):
 
     def _get_user(self, msg, **config):
         try:
-            email = msg['msg']['message']['agent']
+            agent = msg['msg']['message']['agent']
         except KeyError:
             return msg.get('username', 'anitya')
         else:
-            if email.endswith('@fedoraproject.org'):
-                return email.split('@fedoraproject.org')[0]
+            if 'id.fedoraproject.org' in agent:
+                agent = agent.partition(
+                    '.id.fedoraproject.org')[0].partition('//')[-1]
+                return agent
+            elif agent.endswith('@fedoraproject.org'):
+                return agent.split('@fedoraproject.org')[0]
+            elif '@' in agent:
+                return email2fas(agent, **config)
             else:
-                return email2fas(email, **config)
+                return agent
 
     def link(self, msg, **config):
         if msg['msg']['project']:
             proj = msg['msg']['project']['id']
             return "https://release-monitoring.org/project/%s/" % proj
+        elif msg['topic'].endswith('project.flag.set'):
+            return "https://release-monitoring.org/"
         else:
             return "https://release-monitoring.org/distros"
 
@@ -118,20 +127,34 @@ class AnityaProcessor(BaseProcessor):
             return tmpl.format(user=user, project=project, distro=distro)
         elif 'project.version.update' in msg['topic']:
             project = msg['msg']['project']['name']
+
             if 'message' in msg['msg']:
                 message = msg['msg']['message']
             else:
                 message = msg['msg']
+
+            # If this project is mapped to one or more Fedora package,
+            # then just add the mapped packages to make
+            # everyone's emails more readable.
+            # https://github.com/fedora-infra/the-new-hotness/issues/21
+            packages = []
+            for package in message.get('packages', []):
+                if package['distro'] == 'Fedora':
+                    packages.append(package['package_name'])
+            packages = fedmsg.meta.base.BaseConglomerator.list_to_series(
+                packages)
+            odd = message.get('odd_change', False)
             old = message['old_version']
             new = message['upstream_version']
             tmpl = self._(
                 'A new version of "{project}" has been detected:  '
-                '"{new}"')
-            if old:
+                '"{new}", packaged as "{packages}"')
+            if old and not odd:
                 tmpl = self._(
                     'A new version of "{project}" has been detected:  '
-                    '"{new}" in advance of "{old}"')
-            return tmpl.format(project=project, new=new, old=old)
+                    '"{new}" newer than "{old}", packaged as "{packages}"')
+
+            return tmpl.format(project=project, new=new, old=old, packages=packages)
         elif 'project.version.remove' in msg['topic']:
             project = msg['msg']['project']['name']
             version = msg['msg']['message']['version']
@@ -143,16 +166,32 @@ class AnityaProcessor(BaseProcessor):
             tmpl = self._(
                 '{user} deleted the distro "{project}"')
             return tmpl.format(user=user, project=project)
+        elif msg['topic'].endswith('project.flag.set'):
+            action = msg['msg']['message']['state']
+            flagid = msg['msg']['message']['flag']
+            tmpl = self._(
+                '{user} {action} flag "{flagid}"')
+            return tmpl.format(user=user, action=action, flagid=flagid)
+        elif msg['topic'].endswith('project.flag'):
+            project = msg['msg']['project']['name']
+            tmpl = self._(
+                '{user} flagged the project "{project}"')
+            return tmpl.format(user=user, project=project)
         else:
             pass
 
     def secondary_icon(self, msg, **config):
         username = self._get_user(msg, **config)
+        packages = self.packages(msg, **config)
         if username:
             if '@' in username:
-                return gravatar_url_from_email(username)
+                return avatar_url_from_email(username)
             else:
-                return gravatar_url(username)
+                return avatar_url(username)
+        elif packages:
+            tmpl = 'https://apps.fedoraproject.org/packages/' + \
+                'images/icons/%s.png'
+            return tmpl % list(packages)[0]
         else:
             return None
 
@@ -193,6 +232,8 @@ class AnityaProcessor(BaseProcessor):
             return set(['projects/%s' % msg['msg']['project']['name']])
         elif 'project.add' in msg['topic']:
             return set(['projects/%s' % msg['msg']['project']['name']])
+        elif msg['topic'].endswith('project.flag'):
+            return set(['projects/%s' % msg['msg']['project']['name']])
         elif 'distro.add' in msg['topic']:
             distro = msg['msg']['distro']['name']
             return set(['distros/%s' % distro])
@@ -206,6 +247,9 @@ class AnityaProcessor(BaseProcessor):
         elif 'distro.remove' in msg['topic']:
             distro = msg['msg']['distro']['name']
             return set(['distros/%s' % distro])
+        elif msg['topic'].endswith('project.flag.set'):
+            flagid = msg['msg']['message']['flag']
+            return set(['flag/%s' % flagid])
 
         return set([])
 
@@ -229,5 +273,12 @@ class AnityaProcessor(BaseProcessor):
                 for pkg in packages
                 if pkg['distro'].lower() == 'fedora'
             ])
+        elif msg['topic'].endswith('project.flag'):
+            packages = msg['msg'].get('packages', [])
+            return set([
+                pkg['package_name']
+                for pkg in packages
+                if pkg['distro'].lower() == 'fedora'
+            ])
 
         return set([])
