@@ -18,7 +18,7 @@
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-from fasshim import gravatar_url
+from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url
 
 
 class AskbotProcessor(BaseProcessor):
@@ -26,6 +26,7 @@ class AskbotProcessor(BaseProcessor):
     __description__ = "the Fedora 'Ask' Forum"
     __link__ = "https://ask.fedoraproject.org"
     __docs__ = "https://askbot.com"
+    __icon__ = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     __obj__ = "Ask Fedora Qs & As"
 
     # No icon that I can find..
@@ -85,7 +86,7 @@ class AskbotProcessor(BaseProcessor):
         if not user:
             return ""
 
-        return gravatar_url(username=user)
+        return avatar_url(username=user)
 
     def usernames(self, msg, **config):
         users = set()
@@ -121,7 +122,11 @@ class AskbotProcessor(BaseProcessor):
         return objs
 
     def link(self, msg, **config):
-        tmpl = "https://ask.fedoraproject.org/question/{pk}/"
+        if 'stg' in msg['topic']:
+            tmpl = "https://ask.stg.fedoraproject.org/question/{pk}/"
+        else:
+            tmpl = "https://ask.fedoraproject.org/question/{pk}/"
+
         pk = msg['msg']['topmost_post_id']
         post = ""
 
