@@ -18,7 +18,11 @@
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-from fasshim import avatar_url_from_email, avatar_url_from_openid, email2fas
+from fedmsg_meta_fedora_infrastructure.fasshim import \
+        avatar_url_from_email, avatar_url_from_openid, email2fas
+
+from fedmsg_meta_fedora_infrastructure.conglomerators.mailman import \
+        mailman as mailman_conglomerator
 
 import email.utils
 import warnings
@@ -42,12 +46,16 @@ class MailmanProcessor(BaseProcessor):
     __docs__ = ("https://fedoraproject.org/wiki/"
                 "Communicating_and_getting_help#Mailing_Lists")
     __obj__ = "Mailing List Messages"
-    __icon__ = "http://cloud.ohloh.net/attachments/37686/mailman_med.png"
+    __icon__ = "https://apps.fedoraproject.org/img/icons/hyperkitty.png"
+
+    conglomerators = [
+        mailman_conglomerator.ByMessageId,
+    ]
 
     def subtitle(self, msg, **config):
         if 'receive' in msg['topic']:
             lst = msg['msg']['mlist']['list_name']
-            subject = msg['msg']['msg']['subject']
+            subject = msg['msg']['msg']['subject'].replace('\n', ' ')
 
             full_from = msg['msg']['msg']['from']
             user = _email_to_username(_full_email_to_email(full_from))
@@ -82,11 +90,16 @@ class MailmanProcessor(BaseProcessor):
     def link(self, msg, **config):
         base_url = 'https://lists.fedoraproject.org/archives'
         archived_at = msg['msg']['msg']['archived-at']
-        if archived_at.startswith('http'):
+        if archived_at and archived_at.startswith('<'):
+            archived_at = archived_at[1:]
+        if archived_at and archived_at.endswith('>'):
+            archived_at = archived_at[:-1]
+        if archived_at and archived_at.startswith('http'):
             return archived_at
-        else:
+        elif archived_at:
             return base_url + archived_at
-        return base_url + msg['msg']['msg']['archived-at']
+        else:
+            return None
 
     def usernames(self, msg, **config):
         full_from = msg['msg']['msg']['from']
@@ -114,4 +127,7 @@ class MailmanProcessor(BaseProcessor):
         else:
             tokens = [message_id, 'message']
 
+        lst = msg['msg']['mlist']['list_name']
+        tokens = [lst] + tokens
+
         return set(['/'.join(tokens)])
