@@ -17,15 +17,18 @@
 #
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
+import six
+
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-from fasshim import gravatar_url
+from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url
 
 try:
     from collections import OrderedDict
 except ImportError:
     from ordereddict import OrderedDict
 
-import conglomerators.pkgdb.acls
+from fedmsg_meta_fedora_infrastructure.conglomerators.pkgdb import \
+        acls as pkgdb_acls
 
 def get_agent(msg):
     """ Handy hack to handle legacy messages where 'agent' was a list.  """
@@ -44,19 +47,20 @@ class PkgdbProcessor(BaseProcessor):
     __icon__ = ("https://apps.fedoraproject.org/packages/"
                 "images/icons/package_128x128.png")
     conglomerators = [
-        conglomerators.pkgdb.acls.BySubject,
-        conglomerators.pkgdb.acls.ByPackage,
-        conglomerators.pkgdb.acls.ByAgent,
+        pkgdb_acls.BySubject,
+        pkgdb_acls.ByPackage,
+        pkgdb_acls.ByAgent,
     ]
 
     def subtitle(self, msg, **config):
         if 'pkgdb.acl.update' in msg['topic']:
             tmpl = self._(
                 u"{agent} changed {user}'s '{acl}' permission " +
-                "on {package} ({branch}) to '{status}'"
+                "on {namespace}/{package} ({branch}) to '{status}'"
             )
             user = msg['msg']['username']
             status = msg['msg']['status']
+            namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listing']['package']['name']
             acl = msg['msg']['acl']
             agent = get_agent(msg)
@@ -64,17 +68,21 @@ class PkgdbProcessor(BaseProcessor):
             return tmpl.format(
                 agent=agent, acl=acl,
                 user=user, status=status,
-                package=package, branch=branch)
+                package=package, branch=branch,
+                namespace=namespace,
+            )
         elif 'pkgdb.branch.clone' in msg['topic']:
-            tmpl = self._(u"{agent} branched {package} {branch} from {master}")
+            tmpl = self._(u"{agent} branched {namespace}/{package} {branch} from {master}")
             agent = get_agent(msg)
+            namespace = msg['msg'].get('namespace', 'rpms')
             package = msg['msg']['package']
             branch = msg['msg']['branch']
             master = msg['msg']['master']
             return tmpl.format(agent=agent, package=package,
-                               branch=branch, master=master)
+                               branch=branch, master=master,
+                               namespace=namespace)
         elif 'pkgdb.package.update.status' in msg['topic']:
-            tmpl = self._(u"{agent} {verb} {package}{extra}")
+            tmpl = self._(u"{agent} {verb} {namespace}/{package}{extra}")
             extra = ""
 
             # prev_status, status and package_listing only apear in
@@ -103,31 +111,36 @@ class PkgdbProcessor(BaseProcessor):
             agent = get_agent(msg)
 
             try:
+                namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
                 package = msg['msg']['package_listing']['package']['name']
             except KeyError:
+                namespace = msg['msg'].get('namespace', 'rpms')
                 package = msg['msg']['package']
 
             return tmpl.format(agent=agent, package=package, verb=verb,
-                               extra=extra)
+                               extra=extra, namespace=namespace)
         elif msg['topic'].endswith('pkgdb.package.update'):
             agent = get_agent(msg)
 
             try:
+                namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
                 package = msg['msg']['package_listing']['package']['name']
             except KeyError:
+                namespace = msg['msg'].get('namespace', 'rpms')
                 package = msg['msg']['package']
             if isinstance(package, dict):
+                namespace = package.get('namespace', namespace)
                 package = package['name']
 
             if 'fields' in msg['msg']:
                 # New pkgdb2 style
-                tmpl = self._(u"{agent} updated: {fields} of {package}")
+                tmpl = self._(u"{agent} updated: {fields} of {namespace}/{package}")
                 fields = ', '.join(msg['msg'].get('fields'))
-                return tmpl.format(agent=agent, package=package, fields=fields)
+                return tmpl.format(agent=agent, package=package, namespace=namespace, fields=fields)
             else:
                 # old old pkgdb1 style
-                tmpl = self._(u"{agent} made some updates to {package}")
-                return tmpl.format(agent=agent, package=package)
+                tmpl = self._(u"{agent} made some updates to {namespace}/{package}")
+                return tmpl.format(agent=agent, package=package, namespace=namespace)
         elif 'pkgdb.critpath.update' in msg['topic']:
             tmpl = self._(
                 u"{agent} altered the critpath status for some packages")
@@ -135,15 +148,17 @@ class PkgdbProcessor(BaseProcessor):
             return tmpl.format(agent=agent)
         elif msg['topic'].endswith('pkgdb.package.new'):
             tmpl = self._(
-                u"{agent} added a new package '{package}' ({branch})")
+                u"{agent} added a new package '{namespace}/{package}' ({branch})")
             agent = get_agent(msg)
+            namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listing']['package']['name']
             branch = msg['msg']['package_listing']['collection']['branchname']
-            return tmpl.format(agent=agent, package=package, branch=branch)
+            return tmpl.format(agent=agent, package=package, branch=branch, namespace=namespace)
         elif 'pkgdb.acl.request.toggle' in msg['topic']:
             tmpl = self._(
-                u"{agent} has {action} '{acl}' on {package} ({branch})"
+                u"{agent} has {action} '{acl}' on {namespace}/{package} ({branch})"
             )
+            namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listing']['package']['name']
             acl = msg['msg']['acl']
             agent = get_agent(msg)
@@ -151,21 +166,26 @@ class PkgdbProcessor(BaseProcessor):
             action = msg['msg']['acl_action']
             return tmpl.format(
                 agent=agent, acl=acl, action=action,
-                package=package, branch=branch)
+                package=package, branch=branch,
+                namespace=namespace,
+            )
         elif 'pkgdb.package.retire' in msg['topic']:
             tmpl = self._(
-                u"{agent} {action} {package} ({branch})!"
+                u"{agent} {action} {namespace}/{package} ({branch})!"
             )
+            namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listing']['package']['name']
             action = msg['msg']['retirement']
             agent = get_agent(msg)
             branch = msg['msg']['package_listing']['collection']['branchname']
             return tmpl.format(
                 agent=agent, action=action,
-                package=package, branch=branch)
+                package=package, branch=branch,
+                namespace=namespace,
+            )
         elif 'pkgdb.owner.update' in msg['topic']:
             tmpl = self._(
-                u"{agent} changed owner of {package} ({branch}) to '{owner}'")
+                u"{agent} changed owner of {namespace}/{package} ({branch}) to '{owner}'")
 
             # Owners got renamed to points of contact in packagedb2
             try:
@@ -173,6 +193,7 @@ class PkgdbProcessor(BaseProcessor):
             except KeyError:
                 owner = msg['msg']['package_listing']['owner']
 
+            namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listing']['package']['name']
             agent = get_agent(msg)
             branch = msg['msg']['package_listing']['collection']['branchname']
@@ -180,10 +201,12 @@ class PkgdbProcessor(BaseProcessor):
                 agent=agent,
                 owner=owner,
                 package=package,
-                branch=branch)
+                branch=branch,
+                namespace=namespace)
         elif 'pkgdb.acl.user.remove' in msg['topic']:
             tmpl = self._(
-                u"{agent} removed {user} from {package} ({branches})")
+                u"{agent} removed {user} from {namespace}/{package} ({branches})")
+            namespace = msg['msg']['package_listings'][0]['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listings'][0]['package']['name']
             user = msg['msg']['username']
             agent = get_agent(msg)
@@ -195,7 +218,9 @@ class PkgdbProcessor(BaseProcessor):
                 agent=agent,
                 user=user,
                 package=package,
-                branches=branches)
+                branches=branches,
+                namespace=namespace,
+            )
         elif 'pkgdb.branch.start' in msg['topic']:
             tmpl = self._(
                 u"{agent} started a branch of {tobranch} from {frombranch}")
@@ -245,85 +270,137 @@ class PkgdbProcessor(BaseProcessor):
             )
         elif 'pkgdb.package.delete' in msg['topic']:
             tmpl = self._(
-                u"{agent} deleted the '{package}' package from the pkgdb")
+                u"{agent} deleted the '{namespace}/{package}' package from the pkgdb")
             agent = get_agent(msg)
+            namespace = msg['msg']['package'].get('namespace', 'rpms')
             package = msg['msg']['package']['name']
-            return tmpl.format(agent=agent, package=package)
+            return tmpl.format(agent=agent, package=package, namespace=namespace)
         elif 'pkgdb.package.branch.delete' in msg['topic']:
             tmpl = self._(
                 u"{agent} deleted the {branch} branch "
-                "of the '{package}' package")
+                "of the '{namespace}/{package}' package")
             agent = get_agent(msg)
+            namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
             package = msg['msg']['package_listing']['package']['name']
             branch = msg['msg']['package_listing']['collection']['branchname']
-            return tmpl.format(agent=agent, branch=branch, package=package)
+            return tmpl.format(agent=agent, branch=branch, package=package, namespace=namespace)
         elif msg['topic'].endswith('pkgdb.package.branch.new'):
             tmpl = self._(
                 u"{agent} created the branch '{branch}' for the package "
-                "'{package}'")
+                "'{namespace}/{package}'")
             agent = get_agent(msg)
+            namespace = msg['msg']['package'].get('namespace', 'rpms')
             package = msg['msg']['package']['name']
             branch = msg['msg']['package_listing']['collection']['branchname']
-            return tmpl.format(agent=agent, branch=branch, package=package)
+            return tmpl.format(agent=agent, branch=branch, package=package, namespace=namespace)
         elif 'pkgdb.acl.delete' in msg['topic']:
             tmpl = self._(
                 u"{agent} deleted {user}'s {acl} "
-                "rights from {package} ({branch})")
+                "rights from {namespace}/{package} ({branch})")
             _msg = msg['msg']['acl']
+            namespace = _msg['packagelist']['package'].get('namespace', 'rpms')
             package = _msg['packagelist']['package']['name']
             branch = _msg['packagelist']['collection']['branchname']
             acl = _msg['acl']
             user = _msg['fas_name']
             agent = msg['msg']['agent']
             return tmpl.format(agent=agent, user=user, acl=acl,
-                               package=package, branch=branch)
+                               package=package, branch=branch,
+                               namespace=namespace)
         elif msg['topic'].endswith('pkgdb.package.branch.request'):
             tmpl = self._(
-                u"{agent} requested branch {new_branch} from {old_branch} "
-                "on package {package}")
+                u"{agent} requested branch {new_branch} for package {namespace}/{package}")
             _msg = msg['msg']
+            namespace = _msg['package'].get('namespace', 'rpms')
             package = _msg['package']['name']
             new_branch = _msg['collection_to']['branchname']
-            old_branch = _msg['collection_from']['branchname']
             agent = msg['msg']['agent']
             return tmpl.format(agent=agent, new_branch=new_branch,
-                               old_branch=old_branch, package=package)
+                               package=package, namespace=namespace)
         elif msg['topic'].endswith('pkgdb.package.new.request'):
             tmpl = self._(
-                u"{agent} requested package {package} on branch {branch}")
+                u"{agent} requested package {namespace}/{package} on branch {branch}")
             _msg = msg['msg']
+            namespace = _msg['info'].get('namespace', 'rpms')
             package = _msg['info']['pkg_name']
             branch = _msg['collection']['branchname']
             agent = msg['msg']['agent']
-            return tmpl.format(agent=agent, branch=branch, package=package)
+            return tmpl.format(agent=agent, branch=branch, package=package, namespace=namespace)
         elif msg['topic'].endswith('pkgdb.admin.action.status.update'):
             tmpl = self._(
-                u"{agent} updated action {actionid} from {old_status} "
-                "to {new_status}")
+                u"{agent} changed {owner}'s {action} "
+                "for {namespace}/{package} in {branch} "
+                "from {old_status} to {new_status}")
             _msg = msg['msg']
-            actionid = _msg['action']['id']
+
+            agent = _msg['agent']
+            owner = _msg['action']['user']
+
+            branch = _msg['action']['collection']['branchname']
+            try:
+                namespace = _msg['action']['info'].get('namespace', 'rpms')
+                package = _msg['action']['info']['pkg_name']
+            except KeyError:
+                namespace = _msg['action']['package'].get('namespace', 'rpms')
+                package = _msg['action']['package']['name']
+
+            action = _msg['action']['action']
+            substitutes = {
+                'request.package': self._('package request'),
+                'request.branch': self._('branch request'),
+            }
+            action = substitutes.get(action, action)
+
             old_status = _msg['old_status']
             new_status = _msg['new_status']
-            agent = msg['msg']['agent']
-            return tmpl.format(agent=agent, actionid=actionid,
-                               old_status=old_status, new_status=new_status)
+
+            message = _msg['action'].get('message', None)
+            if message:
+                tmpl += self._(" with message: {message}")
+
+            return tmpl.format(
+                agent=agent, owner=owner, action=action,
+                package=package, branch=branch,
+                old_status=old_status, new_status=new_status, message=message,
+                namespace=namespace,
+            )
         elif msg['topic'].endswith('pkgdb.package.critpath.update'):
             tmpl = self._(
                 u"{agent} {action} the critpath flag on the "
-                "{package} package ({branches})")
+                "{namespace}/{package} package ({branches})")
             agent = msg['msg']['agent']
             action = ['unset', 'set'][msg['msg']['critpath']]
+            namespace = msg['msg']['package'].get('namespace', 'rpms')
             package = msg['msg']['package']['name']
             branches = ', '.join(msg['msg']['branches'])
             return tmpl.format(agent=agent, action=action,
-                               package=package, branches=branches)
+                               package=package, branches=branches,
+                               namespace=namespace)
         elif msg['topic'].endswith('pkgdb.package.monitor.update'):
             tmpl = self._(
-                u"{agent} set the monitor flag of {package} to {status}")
+                u"{agent} set the monitor flag of {namespace}/{package} to {status}")
             agent = msg['msg']['agent']
             status = msg['msg']['status']
+            namespace = msg['msg']['package'].get('namespace', 'rpms')
             package = msg['msg']['package']['name']
-            return tmpl.format(agent=agent, status=status, package=package)
+            return tmpl.format(agent=agent, status=status, package=package, namespace=namespace)
+        elif msg['topic'].endswith('pkgdb.package.unretire.request'):
+            tmpl = self._(
+                u"{agent} asks that {namespace}/{package} be unretired on {branch}")
+            agent = msg['msg']['agent']
+            branch = msg['msg']['collection']['branchname']
+            namespace = msg['msg']['package'].get('namespace', 'rpms')
+            package = msg['msg']['package']['name']
+            return tmpl.format(agent=agent, branch=branch, package=package, namespace=namespace)
+        elif msg['topic'].endswith('pkgdb.package.koschei.update'):
+            tmpl = self._(
+                u"{agent} set the koschei monitoring flag of {namespace}/{package} to "
+                "{status}")
+            agent = msg['msg']['agent']
+            status = msg['msg']['status']
+            namespace = msg['msg']['package'].get('namespace', 'rpms')
+            package = msg['msg']['package']['name']
+            return tmpl.format(agent=agent, status=status, package=package, namespace=namespace)
         else:
             raise NotImplementedError("%r" % msg)
 
@@ -343,7 +420,7 @@ class PkgdbProcessor(BaseProcessor):
         if not user:
             return ""
 
-        return gravatar_url(username=user)
+        return avatar_url(username=user)
 
     def usernames(self, msg, **config):
         users = set()
@@ -448,10 +525,14 @@ class PkgdbProcessor(BaseProcessor):
                 user=_msg['agent'],
             ))
         elif msg['topic'].endswith('pkgdb.admin.action.status.update'):
+            try:
+                package = _msg['action']['info']['pkg_name']
+            except KeyError:
+                package = _msg['action']['package']['name']
             objs.add(
                 'action/{actionid}/status/{package}/{branch}/{user}'.format(
                     actionid=_msg['action']['id'],
-                    package=_msg['action']['info']['pkg_name'],
+                    package=package,
                     branch=_msg['action']['collection']['branchname'],
                     user=_msg['agent'],
                 )
@@ -464,50 +545,104 @@ class PkgdbProcessor(BaseProcessor):
                 package=_msg['package']['name'],
                 status=str(_msg['status']).lower())
             )
+        elif msg['topic'].endswith('pkgdb.package.koschei.update'):
+            objs.add(
+                '{package}/koschei/{status}'.format(
+                package=_msg['package']['name'],
+                status=str(_msg['status']).lower())
+            )
+        elif msg['topic'].endswith('pkgdb.package.unretire.request'):
+            objs.add(
+                '{package}/unretire/{branch}'.format(
+                package=_msg['package']['name'],
+                branch=msg['msg']['collection']['branchname'])
+            )
 
         return objs
 
     def packages(self, msg, **config):
+        requested_namespace = config.get('namespace', 'rpms')
         packages = set()
 
         try:
-            packages.add(msg['msg']['package_listing']['package']['name'])
+            package = msg['msg']['package_listing']['package']
+            if 'namespace' not in package or package['namespace'] == requested_namespace:
+                packages.add(package['name'])
         except KeyError:
             pass
 
         try:
             for package in msg['msg']['package_listings']:
-                packages.add(package['package']['name'])
+                package = package['package']
+                if 'namespace' not in package or package['namespace'] == requested_namespace:
+                    packages.add(package['name'])
         except KeyError:
             pass
 
         try:
-            if isinstance(msg['msg']['package'], basestring):
-                packages.add(msg['msg']['package'])
+            if isinstance(msg['msg']['package'], six.string_types):
+                if 'namespace' not in msg['msg'] or \
+                        msg['msg']['namespace'] == requested_namespace:
+                    packages.add(msg['msg']['package'])
             else:
-                packages.add(msg['msg']['package']['name'])
+                package = msg['msg']['package']
+                if 'namespace' not in package or package['namespace'] == requested_namespace:
+                    packages.add(package['name'])
         except (KeyError, TypeError):
             pass
 
         try:
-            packages.add(msg['msg']['acl']['packagelist']['package']['name'])
+            package = msg['msg']['acl']['packagelist']['package']
+            if 'namespace' not in package or package['namespace'] == requested_namespace:
+                packages.add(package['name'])
         except (KeyError, TypeError):
             pass
 
         try:
-            packages.add(msg['msg']['info']['pkg_name'])
+            if 'pkg_namespace' not in msg['msg']['info'] or  \
+                    msg['msg']['info']['pkg_namespace'] == requested_namespace:
+                packages.add(msg['msg']['info']['pkg_name'])
         except (KeyError, TypeError):
             pass
 
         try:
-            packages.add(msg['msg']['action']['info']['pkg_name'])
+            if 'pkg_namespace' not in msg['msg']['action']['info'] or  \
+                    msg['msg']['info']['action']['pkg_namespace'] == requested_namespace:
+                packages.add(msg['msg']['action']['info']['pkg_name'])
+        except (KeyError, TypeError):
+            pass
+
+        try:
+            if 'namespace' not in msg['msg']['action']['package'] or  \
+                    msg['msg']['action']['package']['namespace'] == requested_namespace:
+                packages.add(msg['msg']['action']['package']['name'])
         except (KeyError, TypeError):
             pass
 
         return packages
 
     def link(self, msg, **config):
-        tmpl = "https://admin.fedoraproject.org/pkgdb/package/{package}/"
+        tmpl = "https://admin.fedoraproject.org/pkgdb/package/{namespace}/{package}/"
+
+        if any(map(msg['topic'].__contains__, [
+            'pkgdb.package.new.request',
+        ])):
+            return tmpl.format(
+                namespace=msg['msg']['info'].get('namespace', 'rpms'),
+                package=msg['msg']['info']['pkg_name'],
+            )
+
+
+        if any(map(msg['topic'].__contains__, [
+            'pkgdb.admin.action.status.update',
+        ])):
+            try:
+                namespace = msg['msg']['action']['info'].get('namespace', 'rpms')
+                package = msg['msg']['action']['info']['pkg_name']
+            except KeyError:
+                namespace = msg['msg']['action']['package'].get('namespace', 'rpms')
+                package = msg['msg']['action']['package']['name']
+            return tmpl.format(namespace=namespace, package=package)
 
         if any(map(msg['topic'].__contains__, [
             'pkgdb.acl.update',
@@ -518,13 +653,15 @@ class PkgdbProcessor(BaseProcessor):
             'pkgdb.package.branch.new',
         ])):
             return tmpl.format(
-                package=msg['msg']['package_listing']['package']['name']
+                namespace=msg['msg']['package_listing']['package'].get('namespace', 'rpms'),
+                package=msg['msg']['package_listing']['package']['name'],
             )
 
         if any(map(msg['topic'].__contains__, [
             'pkgdb.acl.user.remove',
         ])):
             return tmpl.format(
+                namespace=msg['msg']['package_listings'][0]['package'].get('namespace', 'rpms'),
                 package=msg['msg']['package_listings'][0]['package']['name']
             )
 
@@ -534,11 +671,14 @@ class PkgdbProcessor(BaseProcessor):
             'package.branch.request',
         ])):
             try:
+                namespace = msg['msg']['package_listing']['package'].get('namespace', 'rpms')
                 package = msg['msg']['package_listing']['package']['name']
             except KeyError:
+                namespace = msg['msg'].get('namespace', 'rpms')
                 package = msg['msg']['package']
             if isinstance(package, dict):
+                namespace = package.get('namespace', namespace)
                 package = package['name']
-            return tmpl.format(package=package)
+            return tmpl.format(namespace=namespace, package=package)
 
         return ""
