@@ -25,13 +25,14 @@ class PlanetProcessor(BaseProcessor):
     __description__ = "the Fedora blog aggregator"
     __link__ = "http://planet.fedoraproject.org/"
     __docs__ = "https://fedoraproject.org/wiki/Planet"
+    __icon__ = "https://apps.fedoraproject.org/img/icons/planet_logo.png"
     __obj__ = "Blog Posts"
 
     def link(self, msg, **config):
         return msg['msg']['post']['link']
 
     def subtitle(self, msg, **config):
-        title = msg['msg']['post']['title']
+        title = msg['msg']['post'].get('title', '(no title found)')
         if 'username' in msg['msg']:
             tmpl = self._('{user} posted "{title}"')
             return tmpl.format(title=title, user=msg['msg']['username'])
@@ -39,6 +40,19 @@ class PlanetProcessor(BaseProcessor):
         tmpl = self._('New post: "{title}"')
         return tmpl.format(title=title)
 
+    def long_form(self, msg, **config):
+        if 'summary' in msg['msg']['post']:
+            return msg['msg']['post']['summary']
+        elif 'content' in msg['msg']['post']:
+            if msg['msg']['post']['content']:
+                return msg['msg']['post']['content'][0]['value']
+
+    def lexer(self, msg, **config):
+        # Be explicit about returning None here.  We don't want to lex the html
+        # from their summary.. but we want to return it literally.  So, don't
+        # implement a lexer here, please.  --ralph
+        return None
+
     def secondary_icon(self, msg, **config):
         return msg['msg'].get('face', None)
 
