@@ -1,5 +1,5 @@
 # This file is part of fedmsg.
-# Copyright (C) 2012-2014 Red Hat, Inc.
+# Copyright (C) 2012-2017 Red Hat, Inc.
 #
 # fedmsg is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -16,31 +16,39 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 #
 # Authors:  Ralph Bean <rbean@redhat.com>
+#           Pierre-Yves Chibon <pingou@pingoured.fr>
 #
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-from fasshim import gravatar_url, gravatar_url_from_email
+from fedmsg_meta_fedora_infrastructure.fasshim import \
+        avatar_url, avatar_url_from_email
 
 import requests
 
 
+already_seen_msg = "This commit already existed in another branch."
+
+
 class SCMProcessor(BaseProcessor):
     __name__ = "git"
     __description__ = "the Fedora version control system"
-    __link__ = "http://pkgs.fedoraproject.org/cgit"
+    __link__ = "https://src.fedoraproject.org/"
     __docs__ = "https://fedoraproject.org/wiki/Using_Fedora_GIT"
     __obj__ = "Package Commits"
     __icon__ = "https://apps.fedoraproject.org/img/icons/git-logo.png"
 
     def secondary_icon(self, msg, **config):
         if '.git.receive' in msg['topic']:
+            if 'username' in msg['msg']['commit']:
+                username = msg['msg']['commit']['username']
+                return avatar_url(username)
             email = msg['msg']['commit']['email']
-            return gravatar_url_from_email(email)
+            return avatar_url_from_email(email)
         elif '.git.lookaside' in msg['topic']:
             username = msg['msg']['agent']
-            return gravatar_url(username)
+            return avatar_url(username)
         elif 'agent' in msg['msg']:
             username = msg['msg']['agent']
-            return gravatar_url(username)
+            return avatar_url(username)
 
     def long_form(self, msg, **config):
         if '.git.receive' in msg['topic']:
@@ -49,12 +57,33 @@ class SCMProcessor(BaseProcessor):
             except KeyError:
                 repo = '.'.join(msg['topic'].split('.')[5:-1])
 
+            namespace = msg['msg']['commit'].get('namespace', 'rpms')
             rev = msg['msg']['commit']['rev']
-            url = 'http://pkgs.fedoraproject.org/cgit/' + \
-                '{repo}.git/patch/?id={rev}'
-            response = requests.get(url.format(repo=repo, rev=rev))
-            if response.status_code == 200:
-                return self.subtitle(msg, **config) + '\n\n' + response.text
+
+            seen = msg['msg']['commit'].get('seen', False)
+            if seen:
+                return already_seen_msg
+
+            url = 'https://src.fedoraproject.org/' + \
+                '{namespace}/{repo}/c/{rev}.patch'
+            url = url.format(namespace=namespace, repo=repo, rev=rev)
+
+            try:
+                response = requests.get(url, timeout=30)
+                if response.status_code == 200:
+                    return response.text
+            except requests.exceptions.RequestException:
+                return "Could not successfully call: {}".format(url)
+        elif '.git.lookaside' in msg['topic']:
+            filename = msg['msg']['filename']
+            xsum = msg['msg']['md5sum']
+            tmpl = self._("{xsum}  {filename}")
+            return tmpl.format(xsum=xsum, filename=filename)
+
+    def lexer(self, msg, **config):
+        if '.git.receive' in msg['topic']:
+            import pygments.lexers.diff
+            return pygments.lexers.diff.DiffLexer()
 
     def subtitle(self, msg, **config):
         if '.git.receive' in msg['topic']:
@@ -63,6 +92,11 @@ class SCMProcessor(BaseProcessor):
             except KeyError:
                 repo = '.'.join(msg['topic'].split('.')[5:-1])
 
+            try:
+                namespace = msg['msg']['commit']['namespace'] + '/'
+            except KeyError:
+                namespace = ''
+
             try:
                 user = msg['msg']['commit']['username']
             except KeyError:
@@ -74,8 +108,8 @@ class SCMProcessor(BaseProcessor):
                 summ += " (..more)"
 
             branch = msg['msg']['commit']['branch']
-            tmpl = self._('{user} pushed to {repo} ({branch}).  "{summary}"')
-            return tmpl.format(user=user, repo=repo,
+            tmpl = self._('{user} pushed to {namespace}{repo} ({branch}).  "{summary}"')
+            return tmpl.format(user=user, repo=repo, namespace=namespace,
                                branch=branch, summary=summ)
         elif '.git.branch' in msg['topic']:
             try:
@@ -85,6 +119,11 @@ class SCMProcessor(BaseProcessor):
                 repo = '.'.join(msg['topic'].split('.')[5:-1])
                 branch = msg['topic'].split('.')[-1]
 
+            try:
+                repo = msg['msg']['commit']['namespace'] + '/' + repo
+            except KeyError:
+                pass
+
             agent = msg['msg']['agent']
             tmpl = self._(
                 "{agent} created branch '{branch}' for the '{repo}' package"
@@ -105,7 +144,7 @@ class SCMProcessor(BaseProcessor):
         elif '.git.pkgdb2branch.start' in msg['topic']:
             tmpl = self._('{agent} started a run of pkgdb2branch')
         elif '.git.pkgdb2branch.complete' in msg['topic']:
-            errors = len(msg['msg']['unbranchedPackages'])
+            errors = len(msg['msg'].get('unbranchedPackages') or [])
             if errors == 0:
                 tmpl = self._(
                     'run of pkgdb2branch started by {agent} completed')
@@ -120,21 +159,23 @@ class SCMProcessor(BaseProcessor):
                     ' with %i errors'
                 ) % errors
 
-        agent = msg['msg']['agent']
+        agent = msg['msg'].get('agent', '(somebody)')
         return tmpl.format(agent=agent)
 
     def link(self, msg, **config):
-        prefix = "http://pkgs.fedoraproject.org/cgit"
+        prefix = "https://src.fedoraproject.org"
         if '.git.receive' in msg['topic']:
             try:
                 repo = msg['msg']['commit']['repo']
             except KeyError:
                 repo = '.'.join(msg['topic'].split('.')[5:-1])
+            namespace = msg['msg']['commit'].get('namespace', 'rpms')
             rev = msg['msg']['commit']['rev']
             branch = msg['msg']['commit']['branch']
-            tmpl = "{prefix}/{repo}.git/commit/?h={branch}&id={rev}"
-            return tmpl.format(prefix=prefix, repo=repo,
-                               branch=branch, rev=rev)
+            tmpl = "{prefix}/{namespace}/{repo}/c/{rev}?branch={branch}"
+            return tmpl.format(
+                prefix=prefix, namespace=namespace, repo=repo,
+                branch=branch, rev=rev)
         elif '.git.branch' in msg['topic']:
             try:
                 repo = msg['msg']['name']
@@ -142,10 +183,12 @@ class SCMProcessor(BaseProcessor):
             except KeyError:
                 repo = '.'.join(msg['topic'].split('.')[5:-1])
                 branch = msg['topic'].split('.')[-1]
-            tmpl = "{prefix}/{repo}.git/log/?h={branch}"
-            return tmpl.format(prefix=prefix, repo=repo, branch=branch)
+            namespace = msg['msg'].get('namespace', 'rpms')
+            tmpl = "{prefix}/{namespace}/{repo}/commits/{branch}"
+            return tmpl.format(
+                prefix=prefix, namespace=namespace, repo=repo, branch=branch)
         elif '.git.lookaside' in msg['topic']:
-            prefix = "http://pkgs.fedoraproject.org/lookaside/pkgs"
+            prefix = "https://src.fedoraproject.org/lookaside/pkgs"
 
             if 'path' in msg['msg']:
                 path = msg['msg']['path']
@@ -171,6 +214,12 @@ class SCMProcessor(BaseProcessor):
             return set()
 
     def packages(self, msg, **config):
+
+        # If its not an rpms/ thing, then its not a package.
+        if 'namespace' in msg['msg'].get('commit', []):
+            if not msg['msg']['commit']['namespace'] in ['rpms', 'rpms-checks']:
+                return set()
+
         if 'git.receive' in msg['topic']:
             try:
                 # Newer fedmsg
