@@ -18,23 +18,31 @@
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-from fasshim import gravatar_url
+from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url
 
+from fedmsg_meta_fedora_infrastructure.conglomerators.tagger \
+    import tags as tagger_tags
 
 class TaggerProcessor(BaseProcessor):
     __name__ = "fedoratagger"
     __description__ = "the Fedora package labeller/tagger"
     __link__ = "https://apps.fedoraproject.org/tagger"
     __docs__ = "https://github.com/ralphbean/fedora-tagger"
+    __icon__ = "https://apps.fedoraproject.org/img/icons/tagger.png"
     __obj__ = "Package Tag Votes"
 
+    conglomerators = [
+        tagger_tags.UpdateByUser,
+        tagger_tags.CreateByUser,
+    ]
+
     def link(self, msg, **config):
         vote = msg.get('msg', {}).get('vote', {})
         pack = vote.get('tag', {}).get('package', None)
 
         # Backwards compat with old tagger messages
         if hasattr(pack, 'keys'):
-            pack = pack.keys()[0]
+            pack = list(pack.keys())[0]
 
         if not pack and 'rating' in msg['msg']:
             pack = msg['msg']['rating']['package']['name']
@@ -55,7 +63,7 @@ class TaggerProcessor(BaseProcessor):
 
             # Backwards compat with old tagger messages
             if hasattr(package, 'keys'):
-                package = package.keys()[0]
+                package = list(package.keys())[0]
 
             if msg['msg']['vote']['like']:
                 verb = "up"
@@ -81,7 +89,7 @@ class TaggerProcessor(BaseProcessor):
 
             # Backwards compat with old tagger messages
             if hasattr(package, 'keys'):
-                package = package.keys()[0]
+                package = list(package.keys())[0]
 
             tmpl = self._('{user} added tag "{tag}" to {package}')
             return tmpl.format(user=user, tag=tag, package=package)
@@ -107,10 +115,10 @@ class TaggerProcessor(BaseProcessor):
         else:
             raise NotImplementedError("%r" % msg)
 
-    def icon(self, msg, **config):
+    def secondary_icon(self, msg, **config):
         usernames = self.usernames(msg, **config)
         if usernames:
-            return gravatar_url(list(usernames)[0])
+            return avatar_url(list(usernames)[0])
         else:
             return self.__icon__
 
@@ -136,7 +144,7 @@ class TaggerProcessor(BaseProcessor):
 
             # Backwards compat with old tagger messages
             if hasattr(package, 'keys'):
-                package = package.keys()[0]
+                package = list(package.keys())[0]
 
             return set([package])
         elif 'fedoratagger.rating.update' in msg['topic']:
