@@ -23,7 +23,7 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
-from common import add_doc
+from .common import add_doc
 
 
 class TestAskbotRetag(Base):
@@ -40,9 +40,8 @@ class TestAskbotRetag(Base):
     expected_subti = "ralph altered tags on askbot question 'some title'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -90,9 +89,8 @@ class TestAskbotNewQuestion(Base):
     expected_subti = "ralph asked the question 'I have a new question'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -135,6 +133,60 @@ class TestAskbotNewQuestion(Base):
     }
 
 
+class LegacyTestAskbotNewQuestionStg(Base):
+    """ Messages get emitted on this topic anytime an `Ask Fedora
+    <https://ask.stg.fedoraproject.org/questions/>`_ question is updated.
+    The snippet we have below is an example of a user posting a brand **new
+    question** to `Ask Fedora <https://ask.stg.fedoraproject.org/questions/>`_.
+    """
+    expected_title = "askbot.post.edit"
+    expected_subti = "ralph asked the question 'I have a new question'"
+    expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
+    expected_secondary_icon = (
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
+    expected_packages = set()
+    expected_usernames = set(['ralph'])
+    expected_objects = set([
+        'tags/lolol',
+        'threads/3',
+    ])
+    expected_link = "https://ask.stg.fedoraproject.org/question/3/"
+    msg = {
+        "i": 2,
+        "msg": {
+            "thread": {
+                "tagnames": [
+                    "lolol"
+                ],
+                "pk": 3,
+                "title": "I have a new question"
+            },
+            "topmost_post_id": 3,
+            "created": True,
+            "timestamp": 1359946267.0,
+            "agent": "ralph",
+            "newly_mentioned_users": [],
+            "diff": "lololol\n\nthis is my entry, I hope that you "
+            "like it so very much.\n ...",
+            "post": {
+                "vote_up_count": 0,
+                "text": "lololol\r\n\r\nthis is my entry, I hope that "
+                "you like it so very much.",
+                "summary": "lololol\n\nthis is my entry, I hope that "
+                "you like it so very much.\n ...",
+                "comment_count": 0,
+                "vote_down_count": 0,
+                "pk": 4,
+                "post_type": "question"
+            }
+        },
+        "topic": "org.fedoraproject.stg.askbot.post.edit",
+        "username": "threebean",
+        "timestamp": 1359946267.401213
+    }
+
+
 class TestAskbotNewAnswer(Base):
     """ Messages get emitted on this topic anytime a question is updated.
     An 'update' includes a new question, a new answer, and a modification
@@ -146,9 +198,8 @@ class TestAskbotNewAnswer(Base):
                       "to the question 'watwatwatwata'")
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph', 'lmacken'])
     expected_objects = set([
@@ -200,9 +251,8 @@ class TestAskbotFlagOffensiveAdd(Base):
     expected_subti = "ralph flagged a question as offensive!"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -251,9 +301,8 @@ class TestAskbotFlagOffensiveRemove(Base):
     expected_subti = "ralph unflagged an answer as offensive..."
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -303,15 +352,11 @@ class TestAskbotUpdatedQuestion(Base):
     expected_subti = "ralph updated the question 'alskdjflaksjdf lakjsf a'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_emails = {'ralph@fedoraproject.org': 'ralph'}
-    #expected_avatars = dict(ralph="http://www.gravatar.com/avatar/" + \
-    #    "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-    #    "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
     expected_objects = set([
         'tags/town',
         'threads/2',
@@ -360,9 +405,8 @@ class TestAskbotUpdatedAnswer(Base):
                       "to the question 'I have a new question'")
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -413,9 +457,8 @@ class TestAskbotAnswerDeleted(Base):
     expected_subti = "ralph deleted an answer on 'test 3 is a charm'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
@@ -460,9 +503,8 @@ class TestAskbotQuestionDeleted(Base):
     expected_subti = "ralph deleted the question 'test 3 is a charm'"
     expected_icon = "https://apps.fedoraproject.org/img/icons/ask_fedora.png"
     expected_secondary_icon = (
-        "http://www.gravatar.com/avatar/"
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F"
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png")
+        "https://seccdn.libravatar.org/avatar/"
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro")
     expected_packages = set()
     expected_usernames = set(['ralph'])
     expected_objects = set([
