@@ -23,7 +23,7 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
-from common import add_doc
+from .common import add_doc
 
 
 class TestNewBadge(Base):
@@ -35,11 +35,11 @@ class TestNewBadge(Base):
     expected_title = "fedbadges.badge.award"
     expected_subti = 'ralph has been awarded the ' + \
         '"Something on your mind" badge'
+    expected_long_form = "You have commented on 2 or more bodhi updates."
     expected_link = "https://badges.fedoraproject.org/user/ralph"
     expected_icon = "http://example.com/image.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set(['something-on-your-mind'])
@@ -92,9 +92,8 @@ class TestRankAdvance(Base):
     expected_subti = "ralph moved to position 1500 on the badges leaderboard"
     expected_link = "https://badges.fedoraproject.org/user/ralph"
     expected_icon = "https://apps.fedoraproject.org/img/icons/badges.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set([])
@@ -127,9 +126,8 @@ class TestFirstLogin(Base):
         "for the first time"
     expected_link = "https://badges.fedoraproject.org/user/ralph"
     expected_icon = "https://apps.fedoraproject.org/img/icons/badges.png"
-    expected_secondary_icon = "http://www.gravatar.com/avatar/" + \
-        "2f933f4364baaabd2d3ab8f0664faef2?s=64&d=http%3A%2F%2F" + \
-        "fedoraproject.org%2Fstatic%2Fimages%2Ffedora_infinity_64x64.png"
+    expected_secondary_icon = "https://seccdn.libravatar.org/avatar/" + \
+        "9c9f7784935381befc302fe3c814f9136e7a33953d0318761669b8643f4df55c?s=64&d=retro"
     expected_packages = set([])
     expected_usernames = set(['ralph'])
     expected_objects = set([])
