@@ -10,6 +10,8 @@ class Base(_Base):
         fedmsg_meta_fedora_infrastructure.fasshim._fas_cache = {
             'threebean': 'ralph',
             'rbean@redhat.com': 'ralph',
+            'puiterwijk@gmail.com': 'puiterwijk',
+            'nicolas.mailhot@laposte.net': 'nim',
         }
         super(Base, self).setUp()
 
