@@ -71,11 +71,10 @@ class TestBodhiConglomerateCommentSameUpdate(
     ]
     expected = [{
         'subtitle': 'hreindl and volter commented on sqlite-3.8.6-2.fc20',
-        'link': 'https://admin.fedoraproject.org/updates/sqlite-3.8.6-2.fc20/',
-        'icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
-        'secondary_icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
+        'subjective': 'hreindl and volter commented on sqlite-3.8.6-2.fc20',
+        'link': 'https://bodhi.fedoraproject.org/updates/sqlite-3.8.6-2.fc20',
+        'icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
+        'secondary_icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
 
         'start_time': 1408787444.0,
         'end_time': 1408799776.0,
@@ -84,6 +83,8 @@ class TestBodhiConglomerateCommentSameUpdate(
 
         'usernames': set(['volter', 'hreindl']),
         'packages': set(['sqlite']),
+        'topics': set(['org.fedoraproject.prod.bodhi.update.comment']),
+        'categories': set(['bodhi']),
         'msg_ids': [
             '2014-10047900-1379-4ede-ba94-8319823541a8',
             '2014-f0205c2a-205e-4c79-aad3-542429b3fca8',
@@ -91,9 +92,10 @@ class TestBodhiConglomerateCommentSameUpdate(
     }, {
         'subtitle': u'hreindl commented on bodhi update '
         'file-5.19-4.fc20 (karma: 1)',
-        'link': 'https://admin.fedoraproject.org/updates/file-5.19-4.fc20',
-        'icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
+        'subjective': u'hreindl commented on bodhi update '
+        'file-5.19-4.fc20 (karma: 1)',
+        'link': 'https://bodhi.fedoraproject.org/updates/file-5.19-4.fc20',
+        'icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         'c82951c2d404ca0cfea20f51b040175ba4d1624f51e8ec366e75565b672e943d'
         '?s=64&d=retro',
@@ -105,6 +107,8 @@ class TestBodhiConglomerateCommentSameUpdate(
 
         'usernames': set(['hreindl']),
         'packages': set(['file']),
+        'topics': set(['org.fedoraproject.prod.bodhi.update.comment']),
+        'categories': set(['bodhi']),
         'msg_ids': ['2014-c1ccc3bb-e9bc-4424-8b99-6fbfa24a128f'],
     } ]
 
@@ -158,9 +162,10 @@ class TestBodhiConglomerateCommentSameUser(
     expected = [{
         'subtitle': 'hreindl commented on file-5.19-4.fc20 '
         'and sqlite-3.8.6-2.fc20',
-        'link': 'https://admin.fedoraproject.org/updates/user/hreindl/',
-        'icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
+        'subjective': 'hreindl commented on file-5.19-4.fc20 '
+        'and sqlite-3.8.6-2.fc20',
+        'link': 'https://bodhi.fedoraproject.org/users/hreindl',
+        'icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         'c82951c2d404ca0cfea20f51b040175ba4d1624f51e8ec366e75565b672e943d'
         '?s=64&d=retro',
@@ -172,6 +177,8 @@ class TestBodhiConglomerateCommentSameUser(
 
         'usernames': set(['hreindl']),
         'packages': set(['sqlite', 'file']),
+        'topics': set(['org.fedoraproject.prod.bodhi.update.comment']),
+        'categories': set(['bodhi']),
         'msg_ids': [
             '2014-10047900-1379-4ede-ba94-8319823541a8',
             '2014-c1ccc3bb-e9bc-4424-8b99-6fbfa24a128f',
