@@ -155,10 +155,11 @@ class TestBodhiConglomerateTestingSamePackageSameUser(
     ]
     expected = [{
         'subtitle': 'pghmcfc submitted 2 perl-Devel-CheckBin '
-        'testing updates for F20 and F19',
-        'link': 'https://admin.fedoraproject.org/updates/perl-Devel-CheckBin/',
-        'icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
+        'testing updates for F19 and F20',
+        'subjective': 'pghmcfc submitted 2 perl-Devel-CheckBin '
+        'testing updates for F19 and F20',
+        'link': 'https://bodhi.fedoraproject.org/updates/perl-Devel-CheckBin',
+        'icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         'f9800f2daf8aabc0b33bca9b4033019c74db77b3baca2d9f98cc629147430e20'
         '?s=64&d=retro',
@@ -170,6 +171,8 @@ class TestBodhiConglomerateTestingSamePackageSameUser(
 
         'usernames': set(['pghmcfc']),
         'packages': set(['perl-Devel-CheckBin']),
+        'topics': set(['org.fedoraproject.prod.bodhi.update.request.testing']),
+        'categories': set(['bodhi']),
         'msg_ids': [
             '2014-3db55159-6a93-4659-8eb7-19a24255df9c',
             '2014-8572040e-4456-48cc-b5c2-b457879e82ae',
@@ -330,13 +333,13 @@ class TestBodhiConglomerateTestingSamePackageDifferentUser(
         },
     ]
     expected = [{
-        'subtitle': 'ralph and pghmcfc submitted 2 perl-Devel-CheckBin '
-        'updates for F20 and F19',
-        'link': 'https://admin.fedoraproject.org/updates/perl-Devel-CheckBin/',
-        'icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
-        'secondary_icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
+        'subtitle': 'pghmcfc and ralph submitted 2 perl-Devel-CheckBin '
+        'updates for F19 and F20',
+        'subjective': 'pghmcfc and ralph submitted 2 perl-Devel-CheckBin '
+        'updates for F19 and F20',
+        'link': 'https://bodhi.fedoraproject.org/updates/perl-Devel-CheckBin',
+        'icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
+        'secondary_icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
 
         'start_time': 1408636105.0,
         'end_time': 1408636112.0,
@@ -345,6 +348,8 @@ class TestBodhiConglomerateTestingSamePackageDifferentUser(
 
         'usernames': set(['pghmcfc', 'ralph']),
         'packages': set(['perl-Devel-CheckBin']),
+        'topics': set(['org.fedoraproject.prod.bodhi.update.request.testing']),
+        'categories': set(['bodhi']),
         'msg_ids': [
             '2014-3db55159-6a93-4659-8eb7-19a24255df9c',
             '2014-8572040e-4456-48cc-b5c2-b457879e82ae',
@@ -506,10 +511,11 @@ class TestBodhiConglomerateTestingSameUserDifferentPackage(
     ]
     expected = [{
         'subtitle': 'pghmcfc submitted nethack and perl-Devel-CheckBin '
-        'updates for F20 and F19',
-        'link': 'https://admin.fedoraproject.org/updates/user/pghmcfc/',
-        'icon': 'https://admin.fedoraproject.org/updates/'
-        'static/images/bodhi-icon-48.png',
+        'updates for F19 and F20',
+        'subjective': 'pghmcfc submitted nethack and perl-Devel-CheckBin '
+        'updates for F19 and F20',
+        'link': 'https://bodhi.fedoraproject.org/users/pghmcfc',
+        'icon': 'https://apps.fedoraproject.org/img/icons/bodhi.png',
         'secondary_icon': 'https://seccdn.libravatar.org/avatar/'
         'f9800f2daf8aabc0b33bca9b4033019c74db77b3baca2d9f98cc629147430e20'
         '?s=64&d=retro',
@@ -521,6 +527,8 @@ class TestBodhiConglomerateTestingSameUserDifferentPackage(
 
         'usernames': set(['pghmcfc']),
         'packages': set(['perl-Devel-CheckBin', 'nethack']),
+        'topics': set(['org.fedoraproject.prod.bodhi.update.request.testing']),
+        'categories': set(['bodhi']),
         'msg_ids': [
             '2014-3db55159-6a93-4659-8eb7-19a24255df9c',
             '2014-8572040e-4456-48cc-b5c2-b457879e82ae',
