@@ -19,11 +19,9 @@
 #
 """ Tests for Koschei messages """
 
-import unittest
-
 from fedmsg_meta_fedora_infrastructure.tests.base import Base
 
-from common import add_doc
+from .common import add_doc
 
 
 class TestKoscheiPackageStateChange(Base):
@@ -36,8 +34,10 @@ class TestKoscheiPackageStateChange(Base):
     """
 
     expected_title = "koschei.package.state.change"
-    expected_subti = "rnv's builds started to fail in f22 (arm)"
-    expected_link = 'http://koschei.cloud.fedoraproject.org/package/rnv'
+    expected_subti = "rnv's builds started to fail in Fedora 22 (arm)"
+    expected_link = 'https://apps.fedoraproject.org/koschei/package/rnv?collection=f22'
+    expected_secondary_icon = \
+        'https://apps.fedoraproject.org/packages/images/icons/rnv.png'
     expected_packages = set(['rnv'])
 
     msg = {
@@ -52,6 +52,41 @@ class TestKoscheiPackageStateChange(Base):
             "new": "failing",
             "koji_instance": "arm",
             "repo": "f22",
+            "collection": "f22",
+            "collection_name": "Fedora 22",
             "groups": ["c", "xml"]
         }
     }
+
+
+class TestKoscheiCollectionStateChange(Base):
+    """ Koschei is a continuous integration system for RPM packages. It tracks
+        dependency changes done in Koji repositories and rebuilds packages whose
+        build dependencies change too much.
+
+    This message type is published by Koschei when collection resolution
+    state changes.
+    """
+
+    expected_title = "koschei.collection.state.change"
+    expected_subti = "Fedora 26 buildroot was broken"
+    expected_link = 'https://apps.fedoraproject.org/koschei/collection/f26'
+
+    msg = {
+        "username": "msimacek",
+        "i": 2,
+        "timestamp": 1412260063,
+        "msg_id": "2014-45d99116-f93e-45ef-8611-04fa2eabbb82",
+        "topic": "org.fedoraproject.dev.koschei.collection.state.change",
+        "msg": {
+            "name": "rnv",
+            "old": "ok",
+            "new": "unresolved",
+            "koji_instance": "primary",
+            "collection": "f26",
+            "collection_name": "Fedora 26"
+        }
+    }
+
+
+add_doc(locals())
