@@ -23,7 +23,7 @@ import unittest
 
 from fedmsg.tests.test_meta import Base
 
-from common import add_doc
+from .common import add_doc
 
 
 class TestPkgdbACLUpdate(Base):
@@ -33,8 +33,8 @@ class TestPkgdbACLUpdate(Base):
 
     expected_title = "pkgdb.acl.update"
     expected_subti = ("ralph changed ralph's 'watchbugzilla' permission on "
-                      "python-sh (EL-6) to 'Awaiting Review'")
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/python-sh/"
+                      "rpms/python-sh (EL-6) to 'Awaiting Review'")
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/python-sh/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -86,8 +86,8 @@ class TestPkgdbPackageNew(Base):
     <http://fedoraproject.org/wiki/Package_SCM_admin_requests>`_.
     """
     expected_title = "pkgdb.package.new"
-    expected_subti = "ralph added a new package 'php-zmq' (devel)"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph added a new package 'rpms/php-zmq' (devel)"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -134,8 +134,8 @@ class TestPkgdbOwnerUpdate(Base):
     the string 'orphan' as its value.)
     """
     expected_title = "pkgdb.owner.update"
-    expected_subti = "ralph changed owner of php-zmq (EL-6) to 'orphan'"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph changed owner of rpms/php-zmq (EL-6) to 'orphan'"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -180,8 +180,8 @@ class TestLegacyPkgdbACLRequestToggle(Base):
     was toggled on a package.
     """
     expected_title = "pkgdb.acl.request.toggle"
-    expected_subti = "ralph has requested 'commit' on php-zmq (EL-6)"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph has requested 'commit' on rpms/php-zmq (EL-6)"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -227,8 +227,8 @@ class TestLegacyPkgdbACLRequestToggle(Base):
 class TestLegacyPkgdbPackageUpdate(Base):
     """ Test old school messages. """
     expected_title = "pkgdb.package.update"
-    expected_subti = "ralph made some updates to php-zmq"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph made some updates to rpms/php-zmq"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -255,8 +255,8 @@ class TestPkgdbPackageUpdateStatus(Base):
     publishes this message when the status of a package is updated.
     """
     expected_title = "pkgdb.package.update.status"
-    expected_subti = "ralph unretired guake in F-18"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/guake/"
+    expected_subti = "ralph unretired rpms/guake in F-18"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/guake/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -303,8 +303,8 @@ class TestPkgdbPackageUpdate(Base):
     publishes this message when metadata for a package is updated.
     """
     expected_title = "pkgdb.package.update"
-    expected_subti = "pkgdb_updater updated: summary, description of guake"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/guake/"
+    expected_subti = "pkgdb_updater updated: summary, description of rpms/guake"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/guake/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -341,8 +341,8 @@ class LegacyTestPkgdbBranchClone(Base):
     package.
     """
     expected_title = "pkgdb.branch.clone"
-    expected_subti = "ralph branched php-zmq f18 from devel"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph branched rpms/php-zmq f18 from devel"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -402,8 +402,8 @@ class TestPkgdbPackageUpdateStatus2(Base):
     Here's an example of a package being retired:
     """
     expected_title = "pkgdb.package.update.status"
-    expected_subti = "till retired libvmime07 in master"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/libvmime07/"
+    expected_subti = "till retired rpms/libvmime07 in master"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/libvmime07/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -480,8 +480,8 @@ class TestLegacyPkgdbPackageRetire(Base):
     publishes messages on this topic when a package is retired.  For example:
     """
     expected_title = "pkgdb.package.retire"
-    expected_subti = "ralph retired php-zmq (EL-6)!"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph retired rpms/php-zmq (EL-6)!"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -527,8 +527,8 @@ class LegacyTestPkgdbUserRemove(Base):
     when a user is removed from a package ACL.
     """
     expected_title = "pkgdb.acl.user.remove"
-    expected_subti = "ralph removed ralph from php-zmq (EL-6, F18)"
-    expected_link = "https://admin.fedoraproject.org/pkgdb/package/php-zmq/"
+    expected_subti = "ralph removed ralph from rpms/php-zmq (EL-6, F18)"
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/php-zmq/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -789,7 +789,7 @@ class TestPkgdbDeletePackage(Base):
     together.
     """
     expected_title = "pkgdb.package.delete"
-    expected_subti = ("ausil deleted the 'pipelight' package from the pkgdb")
+    expected_subti = ("ausil deleted the 'rpms/pipelight' package from the pkgdb")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1170,7 +1170,7 @@ class TestPkgdbDeleteBranch(Base):
     particular package.
     """
     expected_title = "pkgdb.package.branch.delete"
-    expected_subti = "ausil deleted the f21 branch of the 'pipelight' package"
+    expected_subti = "ausil deleted the f21 branch of the 'rpms/pipelight' package"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1267,7 +1267,7 @@ class TestPkgdbDeleteAcl(Base):
     """
     expected_title = "pkgdb.acl.delete"
     expected_subti = ("ausil deleted awjb's watchcommits "
-                      "rights from pipelight (f20)")
+                      "rights from rpms/pipelight (f20)")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1326,8 +1326,7 @@ class TestPkgdbBranchRequest(Base):
     a particular package.
     """
     expected_title = "pkgdb.package.branch.request"
-    expected_subti = ("pingou requested branch epel7 from master on "
-                      "package R-BiocGenerics")
+    expected_subti = ("pingou requested branch epel7 for package rpms/R-BiocGenerics")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1343,14 +1342,6 @@ class TestPkgdbBranchRequest(Base):
         "msg_id": "2014-250329a1-1ccf-4fc4-ad0c-e24365f89c0f",
         "topic": "org.fedoraproject.dev.pkgdb.package.branch.request",
         "msg": {
-            "collection_from": {
-                "status": "Under Development",
-                "dist_tag": ".fc22",
-                "koji_name": "rawhide",
-                "name": "Fedora",
-                "version": "devel",
-                "branchname": "master"
-            },
             "collection_to": {
               "status": "Under Development",
                 "dist_tag": ".el7",
@@ -1380,9 +1371,10 @@ class TestPkgdbPackageRequest(Base):
     to be added into Package DB.
     """
     expected_title = "pkgdb.package.new.request"
-    expected_subti = ("pingou requested package guake on branch master")
+    expected_subti = ("pingou requested package rpms/guake on branch master")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/guake/"
     expected_secondary_icon = (
         "https://seccdn.libravatar.org/avatar/"
         "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
@@ -1427,8 +1419,9 @@ class TestPkgdbAdminActionUpdate(Base):
     Admin Action**.
     """
     expected_title = "pkgdb.admin.action.status.update"
-    expected_subti = ("pingou updated action 18 from Awaiting Review to "
-                "Approved")
+    expected_subti = ("pingou changed pingou's package request for rpms/guake "
+                      "in master from Awaiting Review to Approved")
+    expected_link = "https://admin.fedoraproject.org/pkgdb/package/rpms/guake/"
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1479,6 +1472,66 @@ class TestPkgdbAdminActionUpdate(Base):
         },
     }
 
+class TestPkgdbAdminActionUpdate_Denied(Base):
+    """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
+    publishes messages like these when a request for a new branch/package is
+    **denied/blocked**.
+    """
+    expected_title = "pkgdb.admin.action.status.update"
+    expected_subti = ("pingou changed pingou's branch request for rpms/R-Biobase "
+                      "in epel7 from Awaiting Review to Denied "
+                      "with message: "
+                      "This package should not be branched for EPEL7")
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = (
+        "https://seccdn.libravatar.org/avatar/"
+        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
+        "?s=64&d=retro")
+    expected_packages = set(['R-Biobase'])
+    expected_usernames = set(['pingou'])
+    expected_objects = set(['action/2/status/R-Biobase/epel7/pingou'])
+    msg = {
+        "i": 1,
+        "timestamp": 1421830060,
+        "msg_id": "2015-1acdeda2-e571-4071-a893-cc2b7ba46b02",
+        "topic": "org.fedoraproject.dev.pkgdb.admin.action.status.update",
+        "msg": {
+          "action": {
+            "info": {},
+            "status": "Denied",
+            "package": {
+              "status": "Approved",
+              "upstream_url": "http://bioconductor.org/packages/release/bioc/html/Biobase.html",
+              "monitor": False,
+              "description": "Base functions for Bioconductor (bioconductor.org). Biobase provides\nfunctions that are needed by many other Bioconductor packages or which\nreplace R functions.",
+              "summary": "Base functions for Bioconductor",
+              "acls": [],
+              "creation_date": 1400063778.0,
+              "review_url": None,
+              "name": "R-Biobase"
+            },
+            "date_updated": 1421830060.0,
+            "collection": {
+              "status": "Under Development",
+              "dist_tag": ".el7",
+              "koji_name": "epel7",
+              "name": "Fedora EPEL",
+              "version": "7",
+              "branchname": "epel7"
+            },
+            "user": "pingou",
+            "action": "request.branch",
+            "date_created": 1421227282.0,
+            "message": "This package should not be branched for EPEL7",
+            "id": 2
+          },
+          "old_status": "Awaiting Review",
+          "new_status": "Denied",
+          "agent": "pingou"
+        }
+      }
+
 
 class TestPkgdbCritpathUpdate(Base):
     """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
@@ -1487,7 +1540,7 @@ class TestPkgdbCritpathUpdate(Base):
     """
     expected_title = "pkgdb.package.critpath.update"
     expected_subti = ("pingou set the critpath flag on the "
-                      "openbox package (f21)")
+                      "rpms/openbox package (f21)")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1688,15 +1741,19 @@ class TestPkgdbCritpathUpdate(Base):
         },
     }
 
+    def setUp(self):
+        super(TestPkgdbCritpathUpdate, self).setUp()
+        self.config['namespace'] = 'docker'
 
-class TestPkgdbPackageBranchNew(Base):
+
+class TestPkgdbPackageBranchNewCustomNamespace(Base):
     """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
     publishes messages like these when a **new branch** is created for a
     package.
     """
     expected_title = "pkgdb.package.branch.new"
     expected_subti = ("pingou created the branch 'epel7' for the package "
-                "'R-BSgenome'")
+                "'docker/R-BSgenome'")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1723,7 +1780,8 @@ class TestPkgdbPackageBranchNew(Base):
                     "acls": [],
                     "creation_date": 1400063778.0,
                     "review_url": None,
-                    "name": "R-BSgenome"
+                    "name": "R-BSgenome",
+                    "namespace": "docker",
                 },
                 "point_of_contact": "pingou",
                 "collection": {
@@ -1747,7 +1805,78 @@ class TestPkgdbPackageBranchNew(Base):
                 "acls": [],
                 "creation_date": 1400063778.0,
                 "review_url": None,
-                "name": "R-BSgenome"
+                "name": "R-BSgenome",
+                "namespace": "docker",
+            }
+        }
+    }
+
+    def setUp(self):
+        super(TestPkgdbPackageBranchNewCustomNamespace, self).setUp()
+        self.config['namespace'] = 'docker'
+
+
+class TestPkgdbPackageBranchNew(Base):
+    """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
+    publishes messages like these when a **new branch** is created for a
+    package.
+    """
+    expected_title = "pkgdb.package.branch.new"
+    expected_subti = ("pingou created the branch 'epel7' for the package "
+                "'rpms/R-BSgenome'")
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = (
+        "https://seccdn.libravatar.org/avatar/"
+        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
+        "?s=64&d=retro")
+    expected_packages = set(['R-BSgenome'])
+    expected_usernames = set(['pingou'])
+    expected_objects = set(['R-BSgenome/epel7/new'])
+    msg = {
+        "i": 1,
+        "timestamp": 1408957258,
+        "msg_id": "2014-645038a7-1f95-4a81-aa68-489c0ae55803",
+        "topic": "org.fedoraproject.dev.pkgdb.package.branch.new",
+        "msg": {
+            "package_listing": {
+                "status": "Approved",
+                "package": {
+                    "status": "Approved",
+                    "upstream_url": None,
+                    "description": None,
+                    "summary": "Infrastructure shared by all the "
+                    "Biostrings-based genome",
+                    "acls": [],
+                    "creation_date": 1400063778.0,
+                    "review_url": None,
+                    "name": "R-BSgenome",
+                    "namespace": "rpms",
+                },
+                "point_of_contact": "pingou",
+                "collection": {
+                    "status": "Under Development",
+                    "dist_tag": ".el7",
+                    "koji_name": "epel7",
+                    "name": "Fedora EPEL",
+                    "version": "7",
+                    "branchname": "epel7"
+                },
+                "critpath": False,
+                "status_change": 1408950057.0
+            },
+            "agent": "pingou",
+            "package": {
+                "status": "Approved",
+                "upstream_url": None,
+                "description": None,
+                "summary": "Infrastructure shared by all the "
+                "Biostrings-based genome",
+                "acls": [],
+                "creation_date": 1400063778.0,
+                "review_url": None,
+                "name": "R-BSgenome",
+                "namespace": "rpms",
             }
         }
     }
@@ -1755,11 +1884,12 @@ class TestPkgdbPackageBranchNew(Base):
 
 class TestPkgdbPackageMonitorUpdate(Base):
     """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
-    publishes messages like these when a **new branch** is created for a
-    package.
+    publishes messages like these when someone changes the
+    `monitoring <https://fedoraproject.org/wiki/Upstream_release_monitoring>`_
+    status of a package.
     """
     expected_title = "pkgdb.package.monitor.update"
-    expected_subti = ("pingou set the monitor flag of guake to False")
+    expected_subti = ("pingou set the monitor flag of rpms/guake to False")
     expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
                      "package_128x128.png")
     expected_secondary_icon = (
@@ -1792,6 +1922,244 @@ class TestPkgdbPackageMonitorUpdate(Base):
     }
 
 
+class TestPkgdbPackageUnretireRequest(Base):
+    """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
+    publishes messages like these when someone asks that a package is
+    **unretired**.
+    """
+    expected_title = "pkgdb.package.unretire.request"
+    expected_subti = ("moceap asks that rpms/netbeans-platform8 be unretired on "
+        "master")
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = (
+        "https://seccdn.libravatar.org/avatar/"
+        "360e1873c56312ea5866123f5ffaf4e07d419570b03af7f475c0d20c7501db06"
+        "?s=64&d=retro")
+    expected_packages = set(['netbeans-platform8'])
+    expected_usernames = set(['moceap'])
+    expected_objects = set(['netbeans-platform8/unretire/master'])
+    msg = {
+        'i': 1,
+        'timestamp': 1427823120,
+        'msg_id': '2015-bb28a398-e638-4509-9fa0-57d41c2ae0a4',
+        'topic': 'org.fedoraproject.prod.pkgdb.package.unretire.request',
+        'msg': {
+            'collection': {
+                'status': 'UnderDevelopment',
+                'dist_tag': '.fc23',
+                'koji_name': 'rawhide',
+                'name': 'Fedora',
+                'version': 'devel',
+                'branchname': 'master'
+            },
+            'agent': 'moceap',
+            'package': {
+                'status': 'Approved',
+                'upstream_url': None,
+                'monitor': False,
+                'summary': 'NetBeansPlatform8',
+                'name': 'netbeans-platform8',
+                'acls': [
+                    {
+                        'status': 'Retired',
+                        'point_of_contact': 'orphan',
+                        'package': {
+                            'status': 'Approved',
+                            'upstream_url': None,
+                            'monitor': False,
+                            'summary': 'NetBeansPlatform8',
+                            'name': 'netbeans-platform8',
+                            'acls': [],
+                            'creation_date': 1400070978.0,
+                            'review_url': None,
+                            'description': 'NetBeansPlatformisaframeworkfordevelopmentof\nRichClientSwingApplications.Itcontainspowerful\nmodulesystemandasetofmodulesprovidingvarious\nfunctionalitiesneededforsimplificationof\ndevelopmentofmodulardesktopapplications.'
+                        },
+                        'collection': {
+                            'status': 'UnderDevelopment',
+                            'dist_tag': '.fc23',
+                            'koji_name': 'rawhide',
+                            'name': 'Fedora',
+                            'version': 'devel',
+                            'branchname': 'master'
+                        },
+                        'critpath': False,
+                        'status_change': 1400071169.0
+                    },
+                    {
+                        'status': 'Approved',
+                        'point_of_contact': 'victorv',
+                        'package': {
+                            'status': 'Approved',
+                            'upstream_url': None,
+                            'monitor': False,
+                            'summary': 'NetBeansPlatform8',
+                            'name': 'netbeans-platform8',
+                            'acls': [],
+                            'creation_date': 1400070978.0,
+                            'review_url': None,
+                            'description': 'NetBeansPlatformisaframeworkfordevelopmentof\nRichClientSwingApplications.Itcontainspowerful\nmodulesystemandasetofmodulesprovidingvarious\nfunctionalitiesneededforsimplificationof\ndevelopmentofmodulardesktopapplications.'
+                        },
+                        'collection': {
+                            'status': 'EOL',
+                            'dist_tag': '.fc10',
+                            'koji_name': 'dist-f10',
+                            'name': 'Fedora',
+                            'version': '10',
+                            'branchname': 'f10'
+                        },
+                        'acls': [
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'watchcommits'
+                            },
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'watchbugzilla'
+                            },
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'commit'
+                            },
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'approveacls'
+                            }
+                        ],
+                        'critpath': False,
+                        'status_change': 1400071253.0
+                    },
+                    {
+                        'status': 'Approved',
+                        'point_of_contact': 'victorv',
+                        'package': {
+                            'status': 'Approved',
+                            'upstream_url': None,
+                            'monitor': False,
+                            'summary': 'NetBeansPlatform8',
+                            'name': 'netbeans-platform8',
+                            'acls': [
+
+                            ],
+                            'creation_date': 1400070978.0,
+                            'review_url': None,
+                            'description': 'NetBeansPlatformisaframeworkfordevelopmentof\nRichClientSwingApplications.Itcontainspowerful\nmodulesystemandasetofmodulesprovidingvarious\nfunctionalitiesneededforsimplificationof\ndevelopmentofmodulardesktopapplications.'
+                        },
+                        'collection': {
+                            'status': 'EOL',
+                            'dist_tag': '.fc11',
+                            'koji_name': 'dist-f11',
+                            'name': 'Fedora',
+                            'version': '11',
+                            'branchname': 'f11'
+                        },
+                        'acls': [
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'watchcommits'
+                            },
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'watchbugzilla'
+                            },
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'commit'
+                            },
+                            {
+                                'fas_name': 'victorv',
+                                'status': 'Approved',
+                                'acl': 'approveacls'
+                            }
+                        ],
+                        'critpath': False,
+                        'status_change': 1400071427.0
+                    },
+                    {
+                        'status': 'Orphaned',
+                        'point_of_contact': 'orphan',
+                        'package': {
+                            'status': 'Approved',
+                            'upstream_url': None,
+                            'monitor': False,
+                            'summary': 'NetBeansPlatform8',
+                            'name': 'netbeans-platform8',
+                            'acls': [
+
+                            ],
+                            'creation_date': 1400070978.0,
+                            'review_url': None,
+                            'description': 'NetBeansPlatformisaframeworkfordevelopmentof\nRichClientSwingApplications.Itcontainspowerful\nmodulesystemandasetofmodulesprovidingvarious\nfunctionalitiesneededforsimplificationof\ndevelopmentofmodulardesktopapplications.'
+                        },
+                        'collection': {
+                            'status': 'EOL',
+                            'dist_tag': '.fc12',
+                            'koji_name': 'dist-f12',
+                            'name': 'Fedora',
+                            'version': '12',
+                            'branchname': 'f12'
+                        },
+                        'critpath': False,
+                        'status_change': 1400071659.0
+                    }
+                ],
+                'creation_date': 1400070978.0,
+                'review_url': None,
+                'description': 'NetBeansPlatformisaframeworkfordevelopmentof\nRichClientSwingApplications.Itcontainspowerful\nmodulesystemandasetofmodulesprovidingvarious\nfunctionalitiesneededforsimplificationof\ndevelopmentofmodulardesktopapplications.'
+            }
+        }
+    }
+
+
+class TestPkgdbPackageKoscheiUpdate(Base):
+    """ The Fedora `Package DB <https://admin.fedoraproject.org/pkgdb>`_
+    publishes messages like these when someone changes the
+    `koschei <https://apps.fedoraproject.org/koschei>`_ status of a package.
+    """
+    expected_title = "pkgdb.package.koschei.update"
+    expected_subti = ("pingou set the koschei monitoring flag of rpms/guake to True")
+    expected_icon = ("https://apps.fedoraproject.org/packages/images/icons/"
+                     "package_128x128.png")
+    expected_secondary_icon = (
+        "https://seccdn.libravatar.org/avatar/"
+        "01fe73d687f4db328da1183f2a1b5b22962ca9d9c50f0728aafeac974856311c"
+        "?s=64&d=retro")
+    expected_packages = set(['guake'])
+    expected_usernames = set(['pingou'])
+    expected_objects = set(['guake/koschei/true'])
+    msg = {
+        'username': u'pierrey',
+        'i': 3,
+        'timestamp': 1435313134,
+        'msg_id': u'2015-7d0ecbd6-6892-4b34-98ff-b212d1fef74e',
+        'topic': u'org.fedoraproject.dev.pkgdb.package.koschei.update',
+        'msg': {
+            'status': True,
+            'agent': u'pingou',
+            'package': {
+                'status': u'Approved',
+                'upstream_url': u'http: //www.guake.org/',
+                'koschei_monitor': True,
+                'monitor': False,
+                'summary': u'Drop-downterminalforGNOME',
+                'name': u'guake',
+                    'acls': [
+                ],
+                'creation_date': 1400063778.0,
+                'review_url': None,
+                'description': 'Guake is a drop-down terminal for Gnome'
+            }
+        }
+    }
+
+
 add_doc(locals())
 
 if __name__ == '__main__':
