@@ -18,7 +18,7 @@
 # Authors:  Ralph Bean <rbean@redhat.com>
 #
 from fedmsg_meta_fedora_infrastructure import BaseProcessor
-from fasshim import gravatar_url
+from fedmsg_meta_fedora_infrastructure.fasshim import avatar_url
 
 short_repos = [
     '389',
@@ -97,6 +97,21 @@ class TracProcessor(BaseProcessor):
     __obj__ = "Fedora Hosted Events"
     __icon__ = "https://www.edgewall.org/gfx/trac_bullet.png"
 
+    def long_form(self, msg, **config):
+        if 'ticket' in msg['msg']:
+            comment = msg['msg'].get('comment')
+            description = msg['msg']['ticket'].get('description')
+            summary = msg['msg']['ticket'].get('summary')
+
+            retval = ""
+            if summary:
+                retval += "Summary: " + summary + "\n"
+            if comment:
+                retval += "Comment: " + comment + "\n"
+            elif description:
+                retval += "Description: " + description + "\n"
+            return retval
+
     def subtitle(self, msg, **config):
         if 'page' in msg['msg']:
             old_name = None
@@ -192,7 +207,7 @@ class TracProcessor(BaseProcessor):
         if not user:
             return ""
 
-        return gravatar_url(username=user)
+        return avatar_url(username=user)
 
     def usernames(self, msg, **config):
         users = set()
